#############################
Aggregation function
#############################

.. |br| raw:: html

   <br />

Descriptions of the basic functions are given below.

**Function descriptions:**

.. automodule:: periodAggregation
   :members:
   :member-order: bysource
